.. currentmodule:: sardana.pool.poolelement

:mod:`~sardana.pool.poolelement`
======================================

.. automodule:: sardana.pool.poolelement

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolBaseElement`
    * :class:`PoolElement`

PoolBaseElement
-------------------

.. inheritance-diagram:: PoolBaseElement
    :parts: 1
    
.. autoclass:: PoolBaseElement
    :show-inheritance:
    :members:
    :undoc-members:

PoolElement
--------------------------

.. inheritance-diagram:: PoolElement
    :parts: 1
    
.. autoclass:: PoolElement
    :show-inheritance:
    :members:
    :undoc-members:
